#
# spec file for package ghc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define full_version 9.10.2
%define short_version 9.10.2

%global llvm_major 15

# conditionals
# disable prof, docs, perf build
# bcond_with for production builds: disable quick build
%bcond_with quickbuild

# bcond_without for production builds: use Hadrian buildsystem
%bcond_without hadrian

# bcond_without for production builds: build hadrian
%bcond_without build_hadrian

# bcond_without for production builds: enable debuginfo
%bcond_without ghc_debuginfo

%if %{without ghc_debuginfo}
%undefine _enable_debug_packages
%endif

# build profiling libraries
# build haddock
# perf production build (disable for quick build)
%if %{with quickbuild}
%undefine with_ghc_prof
%undefine with_haddock
%bcond_with perf_build
%else
%bcond_without ghc_prof
%bcond_without haddock
%bcond_without manual
%bcond_without perf_build
%endif

%if %{without hadrian}
# locked together since disabling haddock causes no manuals built
# and disabling haddock still created index.html
# https://gitlab.haskell.org/ghc/ghc/-/issues/15190
%{?with_haddock:%bcond_without manual}
%endif

%global ghc_llvm_archs s390x
%global ghc_unregisterized_arches noarch

%global base_ver 4.20.1.0
%global ghc_compact_ver 0.1.0.0
%global hpc_ver 0.7.0.2
%global hsc2hs_ver 0.68.10
%global ghc_bignum_ver 1.3
%global xhtml_ver 3000.2.2.1

Name:           ghc
Version:        %{short_version}
Release:        4.1
Summary:        The Glorious Glasgow Haskell Compiler
License:        BSD-3-Clause
URL:            https://www.haskell.org/ghc/
Source:         https://downloads.haskell.org/~ghc/%{full_version}/ghc-%{version}-src.tar.xz
Source2:        ghc-rpmlintrc
Source4:        9_8_2-bootstrap-sources.tar.gz
Source5:        ghc-pkg.man
Source6:        haddock.man
Source7:        runghc.man

Patch1:         ghc-gen_contents_index-haddock-path.patch
# https://ghc.haskell.org/trac/ghc/ticket/15689
Patch2:         ghc-Cabal-install-PATH-warning.patch
# PATCH-FIX-UPSTREAM Disable-unboxed-arrays.patch ptrommler@icloud.com -- Do not use unboxed arrays on big-endian platforms. See Haskell Trac #15411.
Patch3:         Disable-unboxed-arrays.patch
Patch200:       ghc-hadrian-s390x-rts--qg.patch
Patch300:       hadrian-9.10-deps.patch
# Backport of MR 13105 (NCG for RISCV64)
Patch243:       riscv64-ncg.patch
Patch400:       gnu23-hp2ps.patch

BuildRequires:  binutils-devel
BuildRequires:  gcc-PIE
BuildRequires:  gcc-c++
BuildRequires:  ghc-bootstrap >= 9.8
BuildRequires:  ghc-bootstrap-helpers >= 1.3
BuildRequires:  ghc-rpm-macros-extra => 2.6.1
BuildRequires:  glibc-devel
BuildRequires:  gmp-devel
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  libffi-devel
BuildRequires:  libdwarf-devel
BuildRequires:  libtool
%ifarch %{ghc_llvm_archs}
BuildRequires:  clang%{llvm_major}
BuildRequires:  llvm%{llvm_major}
BuildRequires:  llvm%{llvm_major}-devel
%endif
BuildRequires:  memory-constraints
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  xz
Requires:       %{name}-compiler = %{version}-%{release}
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-ghc-boot-devel = %{version}-%{release}
Requires:       %{name}-ghc-compact-devel = %{ghc_compact_ver}-%{release}
Requires:       %{name}-ghc-devel = %{version}-%{release}
Requires:       %{name}-ghc-heap-devel = %{version}-%{release}
Requires:       %{name}-ghci-devel = %{version}-%{release}
Requires:       %{name}-hpc-devel = %{hpc_ver}-%{release}
Recommends:     %{name}-compiler-default = %{version}-%{release}
%if %{without ghc_debuginfo}
%undefine _enable_debug_packages
%endif
%if %{with manual}
BuildRequires:  python3-Sphinx
%endif
BuildRequires:  libnuma-devel
%if %{with haddock}
Suggests:       %{name}-doc = %{version}-%{release}
Suggests:       %{name}-doc-index = %{version}-%{release}
%endif
%if %{with manual}
Suggests:       %{name}-manual = %{version}-%{release}
%endif
%if %{with ghc_prof}
Suggests:       %{name}-prof = %{version}-%{release}
%endif

%description
Haskell is the standard purely functional programming language; the
current language version is Haskell 98, agreed in December 1998.

GHC is a state-of-the-art programming suite for Haskell.  Included is
an optimising compiler generating good code for a variety of
platforms, together with an interactive system for convenient, quick
development.  The distribution includes space and time profiling
facilities, a large collection of libraries, and support for various
language extensions, including concurrency, exceptions, and foreign
language interfaces (C, C++, etc).

A wide variety of Haskell related resources (tutorials, libraries,
specifications, documentation, compilers, interprbeters, references,
contact information, links to research groups) are available from the
Haskell home page at <http://www.haskell.org/>.

%package compiler
Summary:        GHC compiler and utilities
License:        BSD-3-Clause
Requires:       gcc
Requires:       ghc-base-devel = %{base_ver}-%{release}
Requires:       %{name}-filesystem = %{version}-%{release}
Provides:       hsc2hs = %{hsc2hs_ver}-%{release}
%ifarch %{ghc_llvm_archs}
Requires:       clang%{llvm_major}
Requires:       llvm%{llvm_major}
%endif

%description compiler
This package contains the GHC compiler, tools and utilities.

The GHC libraries are provided by ghc-devel.
To install all of GHC install package ghc.


%if %{with haddock} || (%{with hadrian} && %{with manual})
%package doc
Summary:        Haskell library documentation meta package
License:        BSD-3-Clause

%description doc
Installing this package causes %{name}-*-doc packages corresponding to
%{name}-*-devel packages to be automatically installed too.

%package doc-index
Summary:        GHC library documentation indexing
License:        BSD-3-Clause
Requires:       %{name}-compiler = %{version}-%{release}
BuildArch:      noarch

%description doc-index
The package enables re-indexing of installed library documention.

%package filesystem
Summary:        Shared directories for Haskell documentation
License:        BSD-3-Clause
BuildArch:      noarch

%description filesystem
This package provides some common directories used for
Haskell libraries documentation.
%endif


%if %{with manual}
%package manual
Summary:        GHC manual
License:        BSD-3-Clause
Requires:       %{name}-filesystem = %{version}-%{release}
BuildArch:      noarch

%description manual
This package provides the User Guide and Haddock manual.
%endif


%global ghc_version_override %{version}
%global ghc_pkg_c_deps ghc-compiler = %{ghc_version_override}-%{release}
%global version %{ghc_version_override}
#!ForceMultiversion
%ghc_lib_subpackage -d Cabal-3.12.1.0
%ghc_lib_subpackage -d Cabal-syntax-3.12.1.0
%ghc_lib_subpackage -d array-0.5.8.0
%ghc_lib_subpackage -d -c gmp-devel,libffi-devel,libdw-devel,libelf-devel,libnuma-devel base-%{base_ver}
%ghc_lib_subpackage -d binary-0.8.9.3
%ghc_lib_subpackage -d bytestring-0.12.2.0
%ghc_lib_subpackage -d containers-0.7
%ghc_lib_subpackage -d deepseq-1.5.0.0
%ghc_lib_subpackage -d directory-1.3.8.5
%ghc_lib_subpackage -d exceptions-0.10.9
%ghc_lib_subpackage -d filepath-1.5.4.0
%ghc_lib_subpackage -d -x ghc-%{ghc_version_override}
%ghc_lib_subpackage -d -x ghc-bignum-%{ghc_bignum_ver}
%ghc_lib_subpackage -d -x ghc-boot-%{ghc_version_override}
%ghc_lib_subpackage -d ghc-boot-th-%{ghc_version_override}
%ghc_lib_subpackage -d -x ghc-compact-%{ghc_compact_ver}
%ghc_lib_subpackage -d ghc-experimental-9.1002.0
%ghc_lib_subpackage -d -x ghc-heap-%{ghc_version_override}
%ghc_lib_subpackage -d ghc-internal-9.1002.0
%ghc_lib_subpackage -d -x ghci-%{ghc_version_override}
%ghc_lib_subpackage -d haskeline-0.8.2.1
%ghc_lib_subpackage -d -x hpc-%{hpc_ver}
%ghc_lib_subpackage -d mtl-2.3.1
%ghc_lib_subpackage -d parsec-3.1.18.0
%ghc_lib_subpackage -d pretty-1.1.3.6
%ghc_lib_subpackage -d process-1.6.25.0
%ghc_lib_subpackage -d stm-2.5.3.1
%ghc_lib_subpackage -d semaphore-compat-1.0.0
%ghc_lib_subpackage -d template-haskell-2.22.0.0
%ghc_lib_subpackage -d -c ncurses-devel terminfo-0.4.1.7
%ghc_lib_subpackage -d text-2.1.2
%ghc_lib_subpackage -d time-1.12.2
%ghc_lib_subpackage -d transformers-0.6.1.1
%ghc_lib_subpackage -d unix-2.8.6.0
%ghc_lib_subpackage -d xhtml-%{xhtml_ver}

# new in 9.10 
%ghc_lib_subpackage -d os-string-2.0.4
%ghc_lib_subpackage -d ghc-toolchain-0.1.0.0
%ghc_lib_subpackage -d ghc-platform-0.1.0.0

%global version %{ghc_version_override}

%package devel
Summary:        GHC development libraries meta package
Requires:       ghc-compiler = %{version}-%{release}
Obsoletes:      ghc-libraries < %{version}-%{release}
Provides:       ghc-libraries = %{version}-%{release}
%{?ghc_packages_list:Requires: %(echo %{ghc_packages_list} | sed -e "s/\([^ ]*\)-\([^ ]*\)/%{name}-\1-devel = \2-%{release},/g")}

%description devel
This is a meta-package for all the development library packages in GHC
except the ghc library, which is installed by the toplevel ghc metapackage.

%if %{with ghc_prof}
%package prof
Summary:        GHC profiling libraries meta package
License:        BSD-3-Clause
Requires:       %{name}-compiler = %{version}-%{release}

%description prof
Installing this package causes %{name}-*-prof packages corresponding to
%{name}-*-devel packages to be automatically installed too.
%endif

%prep
%setup -q
%patch -P 1 -p1
%patch -P 2 -p1
%ifarch s390x
%patch -P 3 -p1
%endif

%ifarch loongarch64 ppc64le s390x riscv64
%patch -P 200 -p1
%endif
%patch -P 243 -p1

%patch -P 300 -p1
%patch -P 400 -p1

rm libffi-tarballs/libffi-*.tar.gz

%build
cp %{SOURCE4} ./
hadrian/bootstrap/bootstrap.py --bootstrap-sources 9_8_2-bootstrap-sources.tar.gz

%global hadrian _build/bin/hadrian

%ghc_set_gcc_flags

export CC=%{_bindir}/gcc
export LD=%{_bindir}/ld
export LANG=C.utf8

autoupdate

python3 boot.source --hadrian

./configure --prefix=%{_prefix} --exec-prefix=%{_exec_prefix} \
  --bindir=%{_bindir} --sbindir=%{_sbindir} --sysconfdir=%{_sysconfdir} \
  --datadir=%{_datadir} --includedir=%{_includedir} --libdir=%{_libdir} \
  --libexecdir=%{_libexecdir} --localstatedir=%{_localstatedir} \
  --sharedstatedir=%{_sharedstatedir} --mandir=%{_mandir} \
  --docdir=%{_docdir}/%{name}-%{version} \
  --with-system-libffi \
%ifarch %{ghc_unregisterized_arches}
  --enable-unregisterised \
%endif
%{nil}

%undefine _ghcdynlibdir

%ifarch %{ghc_llvm_archs}
%global hadrian_llvm +llvm
%endif
%define hadrian_docs %{!?with_haddock:--docs=no-haddocks} %{!?with_manual:--docs=no-sphinx}%{?with_manual:--docs=no-sphinx-pdfs --docs=no-sphinx-man}

%if 0%{?suse_version} >= 1500
%ifarch %{unregisterised_archs}
%limit_build -m 8000
%else
%limit_build -m 2000
%endif
%global jobs_nr %{?_smp_mflags}
%else
%global jobs_nr -j1 
%endif
%{hadrian} %{jobs_nr} --flavour=%{?with_quickbuild:quick+no_profiled_libs}%{!?with_quickbuild:perf%{!?with_ghc_prof:+no_profiled_libs}}%{?hadrian_llvm} %{hadrian_docs} binary-dist-dir --hash-unit-ids

%install

(
cd _build/bindist/ghc-%{version}-*
./configure --prefix=%{buildroot}%{ghclibdir} --bindir=%{buildroot}%{_bindir} --libdir=%{buildroot}%{_libdir} --mandir=%{buildroot}%{_mandir} --docdir=%{buildroot}%{_docdir}/%{name}-%{version}
make install
)
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{ghclibplatform}" > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}.conf

# avoid 'E: binary-or-shlib-defines-rpath'
for i in $(find %{buildroot} -type f -executable -exec sh -c "file {} | grep -q 'dynamically linked'" \; -print); do
  chrpath -d $i
done


%if %{with haddock}
# remove short hashes
for d in %{buildroot}%{ghc_html_libraries_dir}/*/; do
mv $d $(echo $d | sed -e "s/\(.*\)-.*/\\1/")
done
%endif
 
# containers src moved to a subdir
cp -p libraries/containers/containers/LICENSE libraries/containers/LICENSE
# hack for Cabal-syntax/LICENSE
mkdir -p libraries/Cabal-syntax
cp -p libraries/Cabal/Cabal-syntax/LICENSE libraries/Cabal-syntax
# hack for ghc-toolchain
mkdir -p libraries/ghc-toolchain
cp -p LICENSE libraries/ghc-toolchain
rm -f %{name}-*.files


# FIXME replace with ghc_subpackages_list
for i in %{ghc_packages_list}; do
name=$(echo $i | sed -e "s/\(.*\)-.*/\1/")
ver=$(echo $i | sed -e "s/.*-\(.*\)/\1/")
%ghc_gen_filelists $name $ver
echo "%%license libraries/$name/LICENSE" >> %{name}-$name.files
done

echo "%%dir %{ghclibdir}" >> %{name}-base%{?_ghcdynlibdir:-devel}.files

%ghc_gen_filelists ghc %{ghc_version_override}
%ghc_gen_filelists ghc-bignum %{ghc_bignum_ver}
%ghc_gen_filelists ghc-boot %{ghc_version_override}
%ghc_gen_filelists ghc-compact %{ghc_compact_ver}
%ghc_gen_filelists ghc-heap %{ghc_version_override}
%ghc_gen_filelists ghci %{ghc_version_override}
%ghc_gen_filelists hpc %{hpc_ver}

%ghc_gen_filelists ghc-prim 0.12.0
%ghc_gen_filelists integer-gmp 1.1
%ghc_gen_filelists rts 1.0.2

%ghc_merge_filelist ghc-prim base
%ghc_merge_filelist integer-gmp base
%ghc_merge_filelist rts base

# add rts libs
for i in %{buildroot}%{ghclibplatform}/libHSrts*ghc%{ghc_version}.so; do
  echo $i >> %{name}-base.files
done
echo "%{_sysconfdir}/ld.so.conf.d/%{name}.conf" >> %{name}-base.files
if [ -f %{buildroot}%{ghcliblib}/package.conf.d/system-cxx-std-lib-1.0.conf ]; then
ls -d %{buildroot}%{ghcliblib}/package.conf.d/system-cxx-std-lib-1.0.conf >> %{name}-base-devel.files
fi

%if %{with ghc_prof}
ls %{buildroot}%{ghclibdir}/bin/ghc-iserv-prof* >> %{name}-base-prof.files
echo "%%dir %{ghcliblib}/bin"
%endif

sed -i -e "s|^%{buildroot}||g" %{name}-base*.files
sed -i -e "s|%{buildroot}||g" %{buildroot}%{_bindir}/*


%if %{with haddock}
rm %{buildroot}%{_docdir}/ghc-%{version}/archives/libraries.html.tar.xz
%endif
%if %{with manual}
rm %{buildroot}%{_docdir}/ghc-%{version}/archives/Haddock.html.tar.xz
rm %{buildroot}%{_docdir}/ghc-%{version}/archives/users_guide.html.tar.xz
%endif


mkdir -p %{buildroot}%{_mandir}/man1
install -p -m 0644 %{SOURCE5} %{buildroot}%{_mandir}/man1/ghc-pkg.1
install -p -m 0644 %{SOURCE6} %{buildroot}%{_mandir}/man1/haddock.1
install -p -m 0644 %{SOURCE7} %{buildroot}%{_mandir}/man1/runghc.1


rm %{buildroot}%{ghclibdir}/lib/package.conf.d/.stamp
rm %{buildroot}%{ghclibdir}/lib/package.conf.d/*.conf.copy

# https://gitlab.haskell.org/ghc/ghc/-/issues/24121
rm %{buildroot}%{ghclibdir}/share/doc/%{ghcplatform}/*/LICENSE


%check
# Actually, I took this from Jens Petersen's Fedora package
# stolen from ghc6/debian/rules:
#Do some very simple tests that the compiler actually works
export LANG=C.utf8
export LD_LIBRARY_PATH=%{buildroot}%{ghclibplatform}:
GHC=%{buildroot}%{ghclibdir}/bin/ghc
# Do some very simple tests that the compiler actually works
rm -rf testghc
mkdir testghc
echo 'main = putStrLn "Foo"' > testghc/foo.hs
$GHC testghc/foo.hs -o testghc/foo
[ "$(testghc/foo)" = "Foo" ]
rm testghc/*
echo 'main = putStrLn "Foo"' > testghc/foo.hs
$GHC testghc/foo.hs -o testghc/foo -O2
[ "$(testghc/foo)" = "Foo" ]
rm testghc/*
echo 'main = putStrLn "Foo"' > testghc/foo.hs
$GHC testghc/foo.hs -o testghc/foo -dynamic
[ "$(testghc/foo)" = "Foo" ]
rm testghc/*

$GHC --info

%transfiletriggerin compiler -- %{ghcliblib}/package.conf.d
%ghc_pkg_recache
%end

%transfiletriggerpostun compiler -- %{ghcliblib}/package.conf.d
%ghc_pkg_recache
%end

%files
%license LICENSE

%files compiler
%license LICENSE
%doc README.md
%{_bindir}/ghc-%{version}
%{_bindir}/ghc-pkg-%{version}
%{_bindir}/ghci-%{version}
%{_bindir}/hp2ps-%{?with_hadrian:ghc-}%{version}
%{_bindir}/hpc-%{?with_hadrian:ghc-}%{version}
%{_bindir}/hsc2hs-%{?with_hadrian:ghc-}%{version}
%{_bindir}/runghc-%{version}
%{_bindir}/runhaskell-%{version}
%{_bindir}/ghc
%{_bindir}/ghc-pkg
%{_bindir}/ghci
%{_bindir}/haddock
%{_bindir}/hp2ps
%{_bindir}/hpc
%{_bindir}/hsc2hs
%{_bindir}/runghc
%{_bindir}/runhaskell
%dir %{ghclibdir}
%dir %{ghcliblib}
%dir %{ghcliblib}/%{ghcplatform}
%dir %{ghclibdir}/bin
%{ghclibdir}/bin/ghc
%{ghclibdir}/bin/ghc-iserv
%{ghclibdir}/bin/ghc-iserv-dyn
%{ghclibdir}/bin/ghc-pkg
%{ghclibdir}/bin/ghc-toolchain-bin
%{ghclibdir}/bin/hpc
%{ghclibdir}/bin/hsc2hs
%{ghclibdir}/bin/runghc
%{ghclibdir}/bin/hp2ps
%{ghclibdir}/bin/unlit
%{ghclibdir}/bin/ghc-%{version}
%{ghclibdir}/bin/ghc-toolchain-bin-ghc-%{version}
%{ghclibdir}/bin/ghc-iserv-ghc-%{version}
%{ghclibdir}/bin/ghc-iserv-dyn-ghc-%{version}
%{ghclibdir}/bin/ghc-pkg-%{version}
%{ghclibdir}/bin/haddock
%{ghclibdir}/bin/haddock-ghc-%{version}
%{ghclibdir}/bin/hp2ps-ghc-%{version}
%{ghclibdir}/bin/hpc-ghc-%{version}
%{ghclibdir}/bin/hsc2hs-ghc-%{version}
%{ghclibdir}/bin/runghc-%{version}
%{ghclibdir}/bin/runhaskell
%{ghclibdir}/bin/runhaskell-%{version}
%{ghclibdir}/bin/unlit-ghc-%{version}
%{ghcliblib}/ghc-interp.js
%{ghcliblib}/ghc-usage.txt
%{ghcliblib}/ghci-usage.txt
%{ghcliblib}/llvm-passes
%{ghcliblib}/llvm-targets
%{ghcliblib}/post-link.mjs
%{ghcliblib}/prelude.js
%dir %{ghcliblib}/package.conf.d
%ghost %{ghcliblib}/package.conf.d/package.cache
%{ghcliblib}/package.conf.d/package.cache.lock
%{ghcliblib}/settings
%{ghcliblib}/template-hsc.h
%{_mandir}/man1/ghc-pkg.1%{?ext_man}
%{_mandir}/man1/haddock.1%{?ext_man}
%{_mandir}/man1/runghc.1%{?ext_man}
%{_bindir}/haddock-ghc-%{version}
%{ghcliblib}/html
%{ghcliblib}/latex
%if %{with haddock} || (%{with hadrian} && %{with manual})
%{ghc_html_libraries_dir}/prologue.txt
%endif
%if %{with haddock}
%verify(not size mtime) %{ghc_html_libraries_dir}/haddock-bundle.min.js
%verify(not size mtime) %{ghc_html_libraries_dir}/linuwial.css
%verify(not size mtime) %{ghc_html_libraries_dir}/quick-jump.css
%verify(not size mtime) %{ghc_html_libraries_dir}/synopsis.png
%endif
%if %{with manual} && %{without hadrian}
%{_mandir}/man1/ghc.1%{?ext_man}
%endif

%files devel

%if %{with haddock} || (%{with hadrian} && %{with manual})
%files doc
%{ghc_html_dir}/index.html

%files doc-index
%{ghc_html_libraries_dir}/gen_contents_index
%if %{with haddock}
%verify(not size mtime) %{ghc_html_libraries_dir}/doc-index*.html
%verify(not size mtime) %{ghc_html_libraries_dir}/index*.html
%endif

%files filesystem
%dir %_ghc_doc_dir
%dir %ghc_html_dir
%dir %ghc_html_libraries_dir
%endif

%if %{with manual}
%files manual
%{ghc_html_dir}/users_guide
%if %{with hadrian}
%{ghc_html_dir}/Haddock
%else
%if %{with haddock}
%{ghc_html_dir}/haddock
%endif
%endif
%endif

%if %{with ghc_prof}
%files prof
%endif

%changelog
* Thu Jul 24 2025 Ondřej Súkup <mimi.vx@gmail.com>
- add gnu23-hp2ps.patch for build hp2ps with gcc15+
* Thu Jul  3 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Apply ghc-hadrian-s390x-rts--qg.patch on loongarch64 as well
- Set physicalmemory for loongarch64 in _constraints to 16 GB
* Thu May 15 2025 Ondřej Súkup <mimi.vx@gmail.com>
- more work on riscv64-ncg.patch
* Fri May  9 2025 Ondřej Súkup <mimi.vx@gmail.com>
- update to version 9.10.2:
- refreshed patches: hadrian-9.10-deps.patch
    riscv64-ncg.patch
- dropped patches:   os-string-be.patch
    ppc64le-miscompilation.patch
- full chagelog:
  https://downloads.haskell.org/~ghc/9.10.2/docs/users_guide/9.10.2-notes.html
* Mon Nov 25 2024 Andreas Schwab <schwab@suse.de>
- riscv64-ncg.patch: Backport of MR 13105, NCG for RISCV64
- Don't require on llvm on riscv64
* Fri Nov 22 2024 Ondřej Súkup <mimi.vx@gmail.com>
- Update to version 9.10.1. The change log for this release is at:
  https://downloads.haskell.org/~ghc/9.10.1/docs/users_guide/9.10.1-notes.html
- use ghc-bootstrap 9.8.2
- enable numa on all architectures
- cleanup dead parts of specfile
- patch changes:
  * added:
  - hadrian-9.10-deps.patch
  - os-string-be.patch
  - ppc64le-miscompilation.patch
  * dropped:
  - cabal-riscv64.patch
  - ghc-with-interpreter.patch
* Mon Oct 21 2024 Ondřej Súkup <mimi.vx@gmail.com>
- Update to version 9.8.3. The change log for this release is at:
  https://downloads.haskell.org/~ghc/9.8.3/docs/users_guide/9.8.3-notes.html
* Sat Aug  3 2024 Andreas Schwab <schwab@suse.de>
- Adjust memory limits on riscv64 and remove obsolete special case for
  qemu emulation
* Tue May 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Replace %%patchN with %%patch -P N: %%patchN is deprecated.
* Tue Mar 19 2024 Ondřej Súkup <mimi.vx@gmail.com>
-  fix iserv and hpc deps
* Tue Mar 12 2024 Peter Simons <psimons@suse.com>
- Update to version 9.8.2. The change log for this release is at:
  https://downloads.haskell.org/~ghc/9.8.2/docs/users_guide/9.8.2-notes.html.
- Update to version 9.8.1. The change log for this release is at:
  https://downloads.haskell.org/~ghc/9.8.2/docs/users_guide/9.8.1-notes.html.
* Sat Feb 24 2024 Ondřej Súkup <mimi.vx@gmail.com>
- update to 9.6.4
  * Fix a code generator bug on AArch64 platforms resulting in invalid conditional jumps.
  * Fix a simplifier bug that may cause segfaults and core lint failures due to incorrect handling of join points.
  * Ensure unconstrained instance dictionaries get IPE info.
  * Fix a bug where we could silently truncate 64 bit values to 32 bit on 32 bit architectures.
  * Fix a GHCi bug where a failure in the :add command would cause the process to exit.
  * Fix a bug causing suboptimal error messages for certain invalid cyclic module graphs with hs-boot files.
  * Fix a bug causing compiler panics with certain package databases involving unusable units and module reexports
  * Fix some memory leaks in GHCi that manifest on reloads
  * Fix a bug leading to some template haskell splices failing on being reloaded into GHCi due to not clearing the interactive context properly.
  * Fix a type checker crash on certain programs involving implicitly scoped type variables.
  * Fix a bug where certain warning flags were not recognised.
  * Fix an incorrect assertion in the simplifier.
  * Align objects in the data section properly when using the LLVM backend.
  * Ensure concurrent thunk update is sound.
  * Ensure the listAllBlocks function takes the non-moving heap into account.
  * Ensure the non-moving GC is not running when pausing.
  * Fix some non-moving loops and bugs on Windows and LLP64 platforms.
  * Fix a bug where certain programs could have incorrect async exception masking.
  * Ensure we respect maximum event length and don’t overflow into program memory.
  * Ensure we use the right linker flags on AArch64 darwin.
  * Fix a bug where -DNOSMP wasn’t being passed to the C compiler even if the target doesn’t support SMP.
  * Ensure we use the right otool and install_name_tool on Darwin.
  * Fix a bug in ghc-bignum where usage of bigNatIsPowerOf2 might result in out of bounds access.
* Wed Nov 15 2023 Ondřej Súkup <mimi.vx@gmail.com>
- drop ghc-9.6.3-src.tar.xz.sig
* Tue Nov 14 2023 Andreas Schwab <schwab@suse.de>
- ghc-8.0.2-Cabal-dynlibdir.patch, 9604.patch, ghc-pie.patch,
  sphinx7.patch: Remove unused patches
* Tue Nov 14 2023 Andreas Schwab <schwab@suse.de>
- libatomic.patch: Remove unused patch
- ghc-with-interpreter.patch: Hadrian: enable GHCi support on riscv64
- cabal-riscv64.patch: libraries/Cabal: Add support for the 64-bit RISC-V
  architecture
- Adjust constraints for riscv64
* Wed Nov  8 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 9.6.3
- dropped execstack.patch and bytestring.patch
  * Major update of ghc see full release notes on:
  https://downloads.haskell.org/ghc/9.6.3/docs/users_guide/release-notes.html
* Fri Aug 11 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 9.4.6
- remove fix_extlinks.patch and add bytestring.patch
  * Fix a bug where certain dictionaries for undecidable
    instances could end up looping at runtime
  * Fix a compiler panic involving newtype family instances
  * Fix a bug preventing using the command line
    to compile .cmm files to assembly
  * Fix compiler panics with certain RULE pragmas
  * Fix a loop in the simplifier due to a bug in
    the representation of certain fields in interface files
  * Make type equality (~) checks in the presence
    of quantified contrains more robust to argument ordering
  * Fix some segfaults when using UnliftedDataTypes
  * Improve bounds checking with -fcheck-prim-bounds
  * Fix a bug in the simplifier leading to core lint errors
  * Ensure array read operations have proper memory barries
  * Fix a spurious -dcore-lint failure with certain kinds of type family instances
  * Fix a bug with .hie files containing spurious references
    to generated functions in files with partial field selectors
  * With the aarch64 backend, fix a bug arising from lack
    of zero-extension for 8/16 bit add/sub with immediate
  * Fix a number of bugs having to do with default
    representation polymorphic type variables
  * Add support for top-level Addr# literals
  * Fix some tag inference bugs when using the bytecode interpreter
  * Support the foreign import prim calling convention in the bytecode interpreter
  * Support sized literals in the bytecode interpreter
  * Fix a bug with the handling of unboxed tuples in the bytecode interpreter
  * Make the bytecode interpreter more robust when run on optimised code
  * Accurately account for mutator allocations when using the non-moving GC
  * Prevent some segfaults by ensuring that pinned allocations respect block size
  * Fix warnings with clang 14.0.3
  * Allow building documentation with sphinx 6.0.0
  * Fix some dependency tracking bugs with hadrian
* Sun Aug  6 2023 Ondřej Súkup <mimi.vx@gmail.com>
- remove post/postun base as is now handled in macros.ghc-extra
* Wed May 24 2023 Ondřej Súkup <mimi.vx@gmail.com>
- add patch for Sphinx 7 release - sphinx7.patch
- cleanup spec
* Wed May 24 2023 Ondřej Súkup <mimi.vx@gmail.com>
- add sphinx7.patch
* Fri Apr 21 2023 Andreas Schwab <schwab@suse.de>
- libatomic.patch: Remove obsolete patch
- Don't enable unregisterised on riscv64
- Adjust constraints
* Wed Apr 19 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 9.4.5
- drop unused patches:
    ghc-8.0.2-Cabal-dynlibdir.patch
    riscv-tntc.patch
  * Fixes for a number of bug fixes in the simplifier
  * Many bug fixes to the non-moving and parallel GCs
  * A number of improvements to recompilation avoidance with multiple
  home units
  * Fixes for regressions in the typechecker and constraint solver
  * and many more. See the release notes for a full accounting.
-> https://downloads.haskell.org/~ghc/9.4.5/docs/users_guide/9.4.5-notes.html
* Fri Apr  7 2023 Ondřej Súkup <mimi.vx@gmail.com>
- add provides hsc2hs into ghc-compiler
* Fri Mar 17 2023 Ondřej Súkup <mimi.vx@gmail.com>
- build with hadrian
- reintroduced profiling packages
- added man pages: ghc-pkg.man haddock.man runghc.man
- added 9_2_3-bootstrap-sources.tar.gz as hadrian deps
- refreshed patches:
  * fix_extlinks.patch
  * Disable-unboxed-arrays.patch
  * ghc-8.0.2-Cabal-dynlibdir.patch
  * ghc-pie.patch
- removed patches:
  * ghc-armv7-VFPv3D16--NEON.patch
  * buildpath-abi-stability.patch
- added patches:
  * ghc-gen_contents_index-haddock-path.patch
  * ghc-Cabal-install-PATH-warning.patch
  * execstack.patch
  * libatomic.patch
  * riscv-tntc.patch
  * ghc-hadrian-s390x-rts--qg.patch
* Tue Jan 31 2023 Peter Simons <psimons@suse.com>
- Update to GHC version 9.4.4.
  * %%{buildroot}%%{ghclibdir}/include is apparently no longer used by
  the RTS package. Those files now live in /usr/lib64/ghc-9.4.4/rts/include.
  * find %%{buildroot}%%{ghc_html_libraries_dir} -name LICENSE -exec rm '{}' ';'
  no longer works because the directory doesn't exist at the time
  that command is run.
  * The user manual and Haddock documentation is installed into a
  different location. For now, we just list the catchall
  %%{_docdir}/packages/ghc to accept anything.
  * The LICENSE file for Cabal-syntax lives at libraries/Cabal/Cabal-syntax
  instead of the expected place libraries/Cabal-syntax.
  * The package system-cxx-std-lib has no LICENSE file. It's not
  even a proper package, it's just a configuration file that lists
  some compiler and linker flags. To work around the build error
  that causes, we just copy some random LICENSE file into the
  place where our build would expect it.
* Thu Jan 19 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Do not require unversionned llvm since ghc needs a specific
  llvm version. [boo#1207265]
* Tue Jan 17 2023 Peter Simons <psimons@suse.com>
- Apply "fix_extlinks.patch" to work around a bug in Sphinx 6.1.x
  that broke our documentation build. Remove this patch once Sphinx
  is fixed. This patch is a variant of the ghc-9.4.4 patch from
  https://gitlab.haskell.org/ghc/ghc/-/issues/22766. Upstream's
  https://github.com/sphinx-doc/sphinx/issues/11094 has further
  details. [boo#1207214]
* Fri Jul  8 2022 Andreas Schwab <schwab@suse.de>
- execstack.patch: add missing stack note
* Mon Jun 27 2022 Dirk Müller <dmueller@suse.com>
- add ghc.keyring to have source validation enabled
- limit to use llvm12 for Factory as newer versions are not supported
* Fri Apr 29 2022 Martin Liška <mliska@suse.cz>
- Remove dependency on binutils-gold as the package will be removed
  in the future. Gold linker is unmaintained by the upstream project.
* Tue Mar  8 2022 Dirk Müller <dmueller@suse.com>
- add ghc-armv7-VFPv3D16--NEON.patch to use vfpv3-d16 on armv7hl
* Wed Feb  9 2022 Peter Simons <psimons@suse.com>
- add environ.patch to fix build errors with recent gcc
* Fri Sep  3 2021 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.10.7
- drop 4134.patch and refresh ghc-pie.patch
  * portabilit yfixes
  * Export some RTS symbols required for static builds of GHC
  * Fix LLVM version checking logic so it no longer complains
    about supported LLVM versions.
  * Fix some RTS crashes on Darwin due to mixing up the closure
    sizes of the aarch64 and x86-64 backends.
  * Fix a crash on the non-moving GC due to incorrect logic
    for calculating the header size for array write barries
  * Fix a bug in base leading to a high likelihood of space
    leaks when using lazy bytestrings
  * Fix some timer races in the RTS possibly manifesting in #18033 and #20132
  * Fix a number of bugs affecting the RTS m32 allocator
  * Fix a bug where code may be unloaded prematurely
    when using the parallel garbage collector
  * Fix a bug where the linker may during shutdown unload code before
    libraries’ atexit handlers have a chance to run
  * Improve code layout by distiguishing conditional and unconditional branches
  * Add hs-boot file support for -ddump-minimal-imports
  * Ensure hs-boot files are built before source files in GHCs -M mode
  * Fix a long standing GHC API bug affecting clients like HLS where
    async exceptions used to cancel threads during typechecking would be
    caught by the Template Haskell evaluator and reported as compile errors
  * Improve error messages when looking up packages fails
  * Fix a number of quirks in GC accounting
  * Fix a code generation bug which could result in entry of unlifted
    objects in some programs using unboxed sums
  * Ensure that POSIX signals are not delivered to the ticker thread
    when using the pthread itimer implementation.
  * Fix a specialiser bug which could result in the construction
    of recursive dictionaries in some programs
  * Bump containers to 0.6.4.1
  * Do not treat -Winferred-safe-imports warnings as errors.
  * Fix a bug where typechecker plugins could be run with
    an inconsistent typechecker environment
  * Fix a simplifier bug which lead to an exponential
    blow up and excessive memory usage in certain cases
* Fri Jun 25 2021 Ondřej Súkup <mimi.vx@gmail.com>
- add 4134.patch to fix build with Sphinx4
* Mon Mar 15 2021 Dirk Müller <dmueller@suse.com>
- always build against llvm9, also on SLE15 (suse_version == 1500)
  otherwise the resulting build is not working (llvm is 7.x there) (bsc#1181571)
* Tue Feb  9 2021 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.10.4
  * Fix a crash caused by inappropriate garbage of heap-allocated data
    reachable from foreign exports
* Sun Dec 20 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.10.3
  * More robust support for architectures with weak memory ordering
    guarantees (e.g. modern ARM hardware).
  * GHC can now split dynamic objects to accomodate macOS' RPATH size
    limitation when building large projects (#14444)
  * Several correctness bugs in the new low-latency garbage collector
  * Many, many other bug-fixes))
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Oct 14 2020 Ondřej Súkup <mimi.vx@gmail.com>
- force multiversion for subpackages
* Sat Oct  3 2020 Ondřej Súkup <mimi.vx@gmail.com>
- add --enable-unregistered to configure phase on unregistered
  architectures
* Sun Aug  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.10.2
  * Fixes a code generation bug resulting in incorrect code generation
    for foreign calls with complex arguments
  * Fixes a bug causing object merging to fail when the lld linker is in use
  * Introduces a workaround for a Linux kernel bug in the implementation
    of the timerfd mechanism
  * Fixes a few specialiser regressions as well introduces a variety
    of miscellaneous specialiser improvements
  * Fixes a potential loss of sharing due to left operator sections
  * Fix bootstrapping of GHC with the LLVM backend on x86-64
  * few important correctness fixes for the low-latency garbage collector.
* Sun May 31 2020 Ondřej Súkup <mimi.vx@gmail.com>
- cleanup specfile from Leap 42 and older remrants
- drop fix-unregisterised-v8.4-8.6.patch
- drop fix-build-using-unregisterized-v8.4.patch
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update ghc to version 8.10.1. Important changes are:
  * The UnliftedNewtypes extension, allowing newtypes to be wrap
    types of kind other than Type.
  * The StandaloneKindSignatures extension, allowing explicit
    signatures on type constructors.
  * A new, low-latency garbage collector for the oldest generation.
  Please refer to the compiler documentation for all details:
  https://downloads.haskell.org/~ghc/8.10.1/docs/html/users_guide/8.10.1-notes.html
* Thu Feb 27 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.8.3
  * a compiler panic due to over-zealous eta reduction
  * the ability to bootstrap with earlier 8.8 releases has been restored
  * the directory submodule has been updated
  * the process submodule has been updated
* Mon Feb 17 2020 Andreas Schwab <schwab@suse.de>
- Increase memory limit for qemu user-space builds
* Wed Feb  5 2020 Andreas Schwab <schwab@suse.de>
- Fix typo in last change
* Thu Jan 23 2020 Peter Trommler <ptrommler@icloud.com>
- use ghc-bootstrap-helpers on all archs
- lower build env requirements on riscv64
  * make sure we can build on smaller systems
  * adjust parallelism so we don't hog big workers for almost a week
  * many thanks to Stefan Bruens for pointing out the issue and
    helping with the solution
* Tue Jan 21 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints for aarch64
* Thu Jan 16 2020 Peter Trommler <ptrommler@icloud.com>
- drop 0001-Fix-check-whether-GCC-supports-__atomic_-builtins.patch
  * fixed upstream
- drop D5212.patch
  * fixed upstream
- drop fix-build-using-unregisterized-v8.4.patch
  * bootstrap compiler is 8.6.5 now
- refresh fix-unregisterised-v8.4-8.6.patch
- clean up spec file
* Thu Jan 16 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.8.2
  * A bug (Issue #17088) in the compacting garbage collector resulting in segmentation
  faults under specific circumstances. Note that this may affect user programs even
  if they did not explicitly request the compacting GC (using the -c RTS flag)
  since GHC may fallback to compacting collection during times of high memory pressure.
  * A code generator bug (Issue #17334) resulting in GHC panics has been fixed.
  * A typechecker bug (Issue #17112) resulting in GHC panicking on some programs
  has been fixed.
  * A bug (Issue #16707) in the implementation of software transactional memory
  potentially resulting in hanging transactions has been fixed.
  * A bug in the implementation of compact normal forms resulting in segmentation
  faults in some uses (Issue #17044) has been fixed.
* Tue Dec 31 2019 Peter Trommler <ptrommler@icloud.com>
- add fix-unregisterised-v8.4-8.6.patch
  * fix build on s390x and riscv64
* Mon Dec 30 2019 Peter Trommler <ptrommler@icloud.com>
- refresh buildpath-abi-stability.patch
- refresh ghc-8.0.2-Cabal-dynlibdir.patch
- refresh ghc-pie.patch
- enable riscv64
* Sun Dec 29 2019 Ondřej Súkup <mimi.vx@gmail.com>
- use prebuilt alex and happy on Tumbleweed to avoid buildcycle
- Don't require llvm in ghc-compiler for other architectures than arm
* Sat Dec 28 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.8.1 -new stable release
- refresh Disable-unboxed-arrays.patch
- drop allow-riscv-and-riscv64-CPU.patch - merged in upstream
* Mon Sep 23 2019 Peter Trommler <ptrommler@icloud.com>
- add fix-build-using-unregisterized-v8.4.patch
  * fixes unregisterised builds when bootstrap compiler is GHC 8.4
  * fixes build on s390x
* Mon Sep 23 2019 Andreas Schwab <schwab@suse.de>
- Enable build on riscv64
- Add memory constraints for riscv64, restrict to 2 jobs
- allow-riscv-and-riscv64-CPU.patch: recognize riscv64 as architecture
- Apply Disable-unboxed-arrays.patch also on s390x
* Thu Apr 25 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.6.5
  * A build system issue where use of GCC with -flto broke configure was fixed
* Wed Mar 13 2019 Ondřej Súkup <mimi.vx@gmail.com>
- really bump llvm5 to llvm6 requires for ghc-compiler
* Tue Mar 12 2019 Ondřej Súkup <mimi.vx@gmail.com>
- bump llvm req to llvm6
* Wed Mar  6 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.6.4
  * A bug wherein changes in default method definitions would fail
    to trigger recompilation has been fixed
  * A bug wherein plugins would fail to lookup names not in scope
    in the module being compiled has been fixed
  * A bug where some programs involving StaticData would be rejected
    with either a typechecking error or internal compiler error has been fixed
  * A bug where compilation on Windows can fail with linker errors
    referring to __chkstk_ms has been fixed
* Mon Dec 17 2018 Ondřej Súkup <mimi.vx@gmail.com>
- use python3-Sphinx instead deprecated python-sphinx [boo#1119686]
* Sat Dec  8 2018 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.6.3
  * A code generation bug resulting in segmentations faults in some programs
  * bug leading to programs with deep stacks crashing when run with retainer profiling enabled
  * A bug resulting in potential heap corruption during stable name allocation
  * Plugins are now loaded during GHCi sessions
* Wed Nov  7 2018 Ondřej Súkup <mimi.vx@gmail.com>
- dont require memory-constraints on older distros
- dropped reproducible-tmp-names.patch
* Tue Nov  6 2018 Ondřej Súkup <mimi.vx@gmail.com>
- update to 8.6.2
  * Several compiler panics observed in GHC 8.6.1 have been fixed
  * An integer overflow, resulting in some encodeFloat uses returning
    incorrect results, has been fixed
  * A long-standing bug in the LLVM code generator, resulting in incorrect
    floating point evaluation, has been fixed.
  * A long-standing bug exposed in GHC 8.6.1, has been fixed. This issue
    resulted in undefined runtime behavior with some uses of the dataToTag#
    primop. Note that this issue, while less likely to manifest, has existed
    in some form in all GHC releases prior to this release and may result
    in silent, incorrect evaluation.
* Mon Oct 29 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Make use of memory-constraints to avoid OOM errors
* Fri Oct 26 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Remove forced 'make -j2' for aarch64 and %%arm
* Tue Oct  9 2018 ptrommler@icloud.com
- add Disable-unboxed-arrays.patch
  * apply on ppc64 only
  * fixes ppc64 build
- add D5212.patch
  * fix GHCi on big endian platforms
* Tue Oct  2 2018 ptrommler@icloud.com
- cleanup
  * remove unused conditional in configure command
* Tue Oct  2 2018 ptrommler@icloud.com
- update to 8.6.1
- add 0001-Fix-check-whether-GCC-supports-__atomic_-builtins.patch
  * fix __atomic_builtin detection
  * upstream commit ce3897ff
- drop add_armv6l_and_armv7l_target.patch
  * fixed upstream
- drop fix-ppc64le-recognition.patch
  * fixed upstream
- drop fix-build-using-unregisterized-v8.2.patch
  * bootstrap with 8.4.3 works w/o this patch
- refresh ghc-pie.patch
- refresh ghc-8.0.2-Cabal-dyndir.patch
- refresh buildpath-abi-stability.patch
* Sun Sep 30 2018 ptrommler@icloud.com
- Add fix-build-using-unregisterized-v8.2.patch
  * Fix build on s390x
* Thu Sep  6 2018 mmanu84@outlook.de
- Fix armv6 build by adding armv6l to llvm-targets:
  * change add_armv7l_target.patch to add_armv6l_and_armv7l_target.patch
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Sun Jul  1 2018 ptrommler@icloud.com
- Fix dependencies on arm and s390x
* Sun Jun 17 2018 ptrommler@icloud.com
- add fix-ppc64le-recognition.patch
  * recognize powerpc64le as PPC64 in cabal files
* Fri Jun  1 2018 ptrommler@icloud.com
- update to 8.4.3
  * code generation for UnboxedSum fixed
  * compatibility withe newer binutils (as)
  * Cabal issue with abi-depends fixed
* Sun May 27 2018 ptrommler@icloud.com
- Fix build for older openSUSE
- Don't do selfbootstrapping
  * Cuts down build time roughly in half
* Fri May 18 2018 guillaume.gardet@opensuse.org
- Fix armv7 build by adding armv7l to llvm-targets:
  * add_armv7l_target.patch
* Thu Apr 26 2018 ptrommler@icloud.com
- update to 8.4.2
- drop 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
  * fixed upstream
- drop 0001-PPC-Implement-Atomic-operations.patch
  * fixed upstream
- drop 0001-Use-__atomic-intrinsics-for-atomicread-write.patch
  * fixed upstream
- drop D4089.patch
  * fixed upstream
* Thu Apr 26 2018 mimi.vx@gmail.com
- fix BuildRequires for llvm
* Wed Apr 18 2018 mimi.vx@gmail.com
- use %%license macro as used by new ghc-rpm-macros
* Mon Dec 18 2017 ptrommler@icloud.com
- refresh ghc-pie.patch so it applies cleanly
* Sat Dec 16 2017 mimi.vx@gmail.com
- reintroduce ghc-pie.patch (pure upstreams don't work)
* Sat Dec  9 2017 ptrommler@icloud.com
- update to 8.2.2
- Several important correctness issues fixing potential runtime crashes
- A correctness issue leading to undefined behavior in some programs
  making use of STMa fixed
- A runtime system bug which may have manifested as a segmentation fault
  under low-memory conditions fixed
- ghc-pkg now works correctly ihn environments with misconfigured NFS mounts
- GHC can now produce position-independent executables
- Significantly improved type errors
- refresh reproducible-tmp-names.patch
- drop ghc-pie.patch fixed upstream
* Tue Oct 31 2017 ptrommler@icloud.com
- update to 8.2.1
- improved compiler performance
- reliable DWARF debugging information on x86_64 and i386
- aarch64: registerised through LLVM backend (experimental)
- optimized build for platforms with LLVM backend (arm, aarch64)
- improved performance on NUMA systems
- interface file determinism
- various language improvements
- update _constraints
  * ppc64le builds need less memory since 8.2.1
- drop support for ppc and s390
- drop ghc-no-madv-free.patch fixed upstream
- drop 0001-StgCmmPrim-Add-missing-write-barrier.patch
- refresh buildpath-abi-stability.patch
- refresh ghc-8.0.2-Cabal-dynlibdir.patch
- refresh ghc-pie.patch
- refresh reproducible-tmp-names.patch
- refresh 0001-PPC-Implement-Atomic-operations.patch
- refresh D4089.patch
* Tue Oct 17 2017 ptrommler@icloud.com
- add D4089.patch
  * fix GHCi issue on ppc64
  * see Haskell Trac #11262
* Fri Sep 22 2017 ptrommler@icloud.com
- add 0001-Use-__atomic-intrinsics-for-atomicread-write.patch
  * add missing memory barriers on atomic read/write ops
  * fixes upstream ticket #14244
- adjust comment for patch 32
  * the situation with upstream #12537 is improved but not
    solved. Patch 32, however, is correct. There are even more
    memory barriers missing elsewhere in the compiler.
* Sat Sep 16 2017 ptrommler@icloud.com
- add 0001-PPC-Implement-Atomic-operations.patch
  * fixes parallel programs on all PowerPC platforms
  * uptream ticket #12537
- refresh buildpath-abi-stability.patch
* Sun May 28 2017 mimi.vx@gmail.com
- make compatible with new upstream macros
- added patches for more stable abi:
  * buildpath-abi-stability.patch
  * reproducible-tmp-names.patch
* Sat May  6 2017 meissner@suse.com
- enable for global PIE support:
  - the compiler is built without PIE support due to the bootstrap
    libraries being non-PIE using BuildIgnore: gcc-PIE
  - the compiler itself builds -fPIC objects all the time,
    which should make all ghc compiled binaries be PIE.
- ghc-pie.patch: enable default -fPIC on Linux/x86_64
* Sun Jan 22 2017 peter.trommler@ohm-hochschule.de
- comment for patch 100
- refresh ghc-no-madv-free.patch with upstream patch
  * upstream fix for Haskell Trac #12865
  * Haskell Trac #12495 is a duplicate
* Sat Jan 21 2017 mimi.vx@gmail.com
- update to 8.0.2
- drop patches merged by upstream:
  * D2495.patch
- refreshed patches:
  * 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
  * 0001-StgCmmPrim-Add-missing-write-barrier.patch
  * ghc-no-madv-free.patch
- added ghc-8.0.2-Cabal-dynlibdir.patch by Jens Petersen simplifing
    haskell packaging
  + Interface files produced by GHC should now be deterministic ( boo#998972 )
  + A bug has been fixed that caused standalone derived Ix instances
    to fail for GADTs with exactly one constructor
  + Compatibility fixes recent Linux distributions.
* Fri Jan 20 2017 peter.trommler@ohm-hochschule.de
- drop D2844.patch
  * the patch causes more issues with parallel builds
- fixes boo#1020909
* Fri Dec 16 2016 peter.trommler@ohm-hochschule.de
- add D2844.patch
  * fix issues with parallel builds
* Fri Oct 14 2016 mimi.vx@gmail.com
- make compatible with new ghc-rpm-macros
* Wed Sep 28 2016 peter.trommler@ohm-hochschule.de
- update to 8.0.1
- drop patches fixed upstream:
  * drop atomic-cast.patch
  * drop cabal-show-detail-direct.patch
  * drop 0001-link-command-line-libs-to-temp-so.patch
  * drop 0001-implement-native-code-generator-for-ppc64.patch
  * drop ghc.git-b29f20.patch
  * drop u_terminfo_0402.patch
  * drop u_Cabal_update.patch
  * drop u_haskeline_update.patch
  * drop 0001-Fix-misspelled-WORDS_BIGENDIAN-macro.patch
  * drop D2214.patch
  * drop D2225.patch
- refresh 0001-StgCmmPrim-Add-missing-write-barrier.patch
- refresh 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
- add ghc-no-madv-free.patch to fix "unable to decommit memory:
  Invalid argument" errors GHC reports due to a misdetected
  MADV_FREE capability. The configure script sees the symbol define
  by glibc, but unfortunately this doesn't mean that the running
  kernel actually supports the feature, too. The upstream ticket
  https://ghc.haskell.org/trac/ghc/ticket/12495 has more details.
  Thanks to @psimons
- GHC produces debug information on x86 and x86_64
- aarch64 has LLVM backend (requires llvm-3.7)
- native code generator for powerpc64[le] (openSUSE contribution!)
- disable html doc on SLE, we don't have python-sphinx
  * Thanks @mimi_vx
* Tue Sep 27 2016 peter.trommler@ohm-hochschule.de
- add D2495.patch
  * missing memory barrier on PowerPC, ARM
- add 0001-StgCmmPrim-Add-missing-write-barrier.patch
  * another issing memory barrier on PowerPC, ARM
- add 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
  * fix bug in code generator
  * fixes build of ghc-zeromq4-haskell on powerpc64[le]
* Thu Aug 18 2016 mimi.vx@gmail.com
- fix boo#994268
* Tue May 17 2016 peter.trommler@ohm-hochschule.de
- add D2225.patch
  * backport of upstream patch accepted for ghc 8.0.1
  * fix SMP primitives on all powerpc archs
* Sat May 14 2016 peter.trommler@ohm-hochschule.de
- add D2214.patch
  * backport of upstream patch slated for ghc 8.0.2
  * fix issue in code PowerPC code generator (32 bit and 64 bit)
- add 0001-Fix-misspelled-WORDS_BIGENDIAN-macro.patch
  * backport of upstream fix slated for ghc 8.0.2
  * fix bytestring library on big-endian archs
  * fix wrong results in ghc-pureMD5 and others on big-endian
* Tue Apr 19 2016 mimi.vx@gmail.com
- update haskeline to 0.7.2.3
- refresh u_haskeline_update.patch
  * Fix hsc2hs-related warning on ghc-8
  * Fix the behavior of ctrl-W in the emacs bindings
  * Point to github instead of trac
* Tue Mar  8 2016 mimi.vx@gmail.com
- update Cabal to 1.22.8.0
- refresh u_Cabal_update.patch
  * Distribution.Simple.Setup: remove job cap
  * Check all object file suffixes for recompilation
  * Move source files under 'src/'.
* Wed Feb 17 2016 peter.trommler@ohm-hochschule.de
- limit parallel jobs to two on aarch64
  * aarch64 runs out of memory with too many parallel compiles
* Sun Feb 14 2016 peter.trommler@ohm-hochschule.de
- add missing C library dependency to terminfo devel package
* Sun Feb  7 2016 mimi.vx@gmail.com
- update haskeline to 0.7.2.2
- add u_haskeline_update.patch
  * canonicalize AMP instances to make the code more future proof
  * Generalize constraints for InputT instances
  * Bump upper bounds on base and transformers
  * Make Haskeline `-Wtabs` clean
* Tue Jan 26 2016 mimi.vx@gmail.com
- update Cabal to 1.22.7.0
- refresh u_Cabal_update.patch
  * Backport #3012 to the 1.22 branch
  * Add foldl' import
  * The Cabal part for fully gcc-like response files
* Tue Jan  5 2016 peter.trommler@ohm-hochschule.de
- update tarball to 7.10.3b
  * some documentation files were missing in the original
  7.10.3 tarball
- add 0001-link-command-line-libs-to-temp-so.patch
  * fix panic in GHCi when linking against C library specified
  as command line argument (-l<lib>)
  * currently under upstream review
  * fix Haskell trac #10458
* Mon Dec 28 2015 mimi.vx@gmail.com
- update Cabal to 1.22.6.0
- add u_Cabal_update.patch --  update of Cabal
  * Relax upper bound to allow upcoming binary-0.8
* Mon Dec 21 2015 mimi.vx@gmail.com
- update terminfo to 0.4.0.2
- drop remove-cur_term-usage.patch - merged by upstream
- add u_terminfo_0402.patch -- update of terminfo
* Mon Dec  7 2015 mimi.vx@gmail.com
- update Cabal to 1.22.5.0
  * Don't recompile C sources unless needed
  * Support Haddock response files.
  * Add frameworks when linking a dynamic library.
* Tue Dec  1 2015 mimi.vx@gmail.com
- use upstream variant of remove-cur_term-usage.patch
* Tue Oct  6 2015 peter.trommler@ohm-hochschule.de
- update to 7.10.3
- add cabal-show-detail-direct.patch -- Fix testsuites with large output.
    Debian patch. Thanks Joachim for suggesting it in Haskell #10870!
- add ghc.git-b29f20.patch
  * fixes upstream #7830
  * fix ghc 7.10.2 failing to bootstrap ghc head on ppc
  and perhaps ppc64 with some optimizations enabled
  * backport of my patch for upcoming ghc 8.0.1
* Mon Oct  5 2015 schwab@suse.de
- atomic-cast.patch: fix signature of atomic bultins
- ghc-7.8-arm-use-ld-gold.patch: remove obsolete patch
* Sat Oct  3 2015 sbahling@suse.com
- Remove ncurses6.patch - it's not so easy ;)
- Add remove-cur_term-usage.patch to remove the need to access the
  cur_term global which isn't available in the openSUSE ncurses6
  build.
* Sat Oct  3 2015 mimi.vx@gmail.com
- Add choice for libffi in openSUSE:Leap:42.1
* Sun Sep 20 2015 mimi.vx@gmail.com
- remove llvm from requires
- add ncurses6.patch to fix build with ncurses6, all thanks goes to
  Tomas Cech sleep_walker@opensuse.org
* Mon Aug 10 2015 peter.trommler@ohm-hochschule.de
- update to 7.10.2
  * type checker fixes
  * fixes for Aarch64 support
  * fix deadlock in runtime system when scheduling garbage collection
- 7.10.1 highlights
  * implement Applicative Monad Proposal
  * implement Burning Bridges Proposal
  * support for partial type signatures
  * reimplement integer-gmp
  * support plugins in type checker (experimental!)
- drop llvm-powerpc64-datalayout.patch
  * this patch was incomplete all along and now we have our native
  code generator
- drop ghc-cabal-unversion-docdir.patch
  * ghc-rpm-macros is following ghc's doc layout so no need to patch
- drop D349.patch
  * fixed upstream
- drop integer-gmp.patch
  * we do not support SLE11 anymore
- drop ghc-7.8.2-cgen-constify.patch
  * fixed upstream
- drop D560.patch
  * fixed upstream
- drop ghc-glibc-2.20_BSD_SOURCE.patch
  * fixed upstream
- drop ghc-arm64.patch
  * fixed upstream
- drop ghc-config.mk.in-Enable-SMP-and-GHCi-support-for-Aarch64.patch
  * fixed upstream
- refresh 0001-implement-native-code-generator-for-ppc64.patch
- disable ghc-7.8-arm-use-ld-gold.patch
  * not sure we need this, must be rebased if we do
* Fri Jul 17 2015 peter.trommler@ohm-hochschule.de
- add ghc-config.mk.in-Enable-SMP-and-GHCi-support-for-Aarch64.patch
  * enable SMP and GHCi on Aarch64
- add ghc-7.8-arm-use-ld-gold.patch
  * Aarch64 needs gold linker
* Fri May 29 2015 peter.trommler@ohm-hochschule.de
- refresh ghc-arm64.patch
- unconditionally apply ghc-arm64.patch
* Thu May 28 2015 peter.trommler@ohm-hochschule.de
- add backport of powerpc64le native code generator to
  0001-implement-native-code-generator-for-ppc64.patch
- refresh D349.patch
* Thu May 28 2015 ro@suse.de
- on s390/s390x use "make -j2" to stabilize abi hashes
  (see also redhat bug 1212374)
* Tue May 26 2015 mimi.vx@gmail.com
- disable llvm on arm64
* Thu May 21 2015 ro@suse.de
- re-diffed ghc-arm64.patch
* Thu May 21 2015 ro@suse.de
- add ghc-arm64.patch for aarch64
- add aarch64, s390, s390x to ExclusiveArch
* Tue Apr 14 2015 mimi.vx@gmail.com
- remove unneeded conditions
* Mon Apr 13 2015 mimi.vx@gmail.com
- chnage constraints to 12G for disk and 4G for ram
* Sun Mar 15 2015 peter.trommler@ohm-hochschule.de
- add ghc-glibc-2.20_BSD_SOURCE.patch
  * fixes build on unregisterised architectures (openSUSE: ppc64le)
* Mon Feb 23 2015 peter.trommler@ohm-hochschule.de
- drop ghc-cabal-unversion-docdir.patch
  * ghc-rpm-macros follows upstream ghc again
* Wed Feb  4 2015 mimi.vx@gmail.com
  + add ghc-glibc-2.20_BSD_SOURCE.patch from fedora
- updated to 7.8.4
  + removed D177.patch (in upstream)
  + removed D173.patch (in upstream)
  + removed ghc.git-e18525f.patch (in upstream)
  + refresh 0001-implement-native-code-generator-for-ppc64.patch
  * A critical bug in the LLVM backend which would cause the compiler to generate incorrect code has been fixed (issue #9439).
  * Several bugs in the code generator have been fixed for unregisterised platforms, such as 64bit PowerPC (issue #8819 and #8849).
  * A bug that could cause GHC's constructor specialization pass (enabled by default at -O2, or via -fspec-constr) to loop forever and consume large amounts of memory has been fixed (issue #8960).
  * A bug that would cause GHC to fail when attempting to determine GCC's version information in non-english locales has been fixed (issue #8825).
  * A minor bug that allowed GHC to seemingly import (but not use) private data constructors has been fixed (issue #9006).
  * A bug in the register allocator which would cause GHC to crash during compilation has been fixed (issue #9303).
  * A bug that caused the compiler to panic on some input C-- code has been fixed (issue #9329).
  * A few various minor deadlocks in the runtime system when using forkProcess have been fixed.
  * A bug which made blocked STM transactions non-interruptible has been fixed (issue #9379).
  * A bug in the compiler which broke pattern synonym imports across modules in Haddock has been fixed (issue #9417).
  * A minor bug in the code generator in which the popCnt16# did not zero-extend its result has been fixed (issue #9435).
  * A bug which caused the compiler to panic on pattern synonyms inside a class declaration has been fixed (issue #9705).
  * A bug in the typechecker revolving around un-saturated type family applications has been fixed (issue #9433).
  * Several bugs have been fixed causing problems with building GHC on ARM (issues #8951, #9620, #9336, and #9552).
  * A bug in the typechecker that could cause an infinite loop when using superclasses in a cycle has been fixed (issue #9415).
  * A bug causing corruption in signal handling with the single-threaded runtime system has been fixed (issue #9817).
  * A bug that could cause compiled programs to crash due to use of overlapping type families has been fixed (issue #9371).
  * A bug in the inliner that caused certain expressions within unboxed tuples to not be properly evaluated has been fixed (issue #9390).
  * A bug that caused the compiler to not always properly detect LLVM tools (particularly on Windows) has been fixed (issue #7143).
  * A bug that prevented GHC from deriving Generic1 instances for data families has been fixed (#9563).
  * A bug that caused type inference to infer the incorrect type in the presence of certain type families and constraints has been fixed (issue #9316).
* Tue Feb  3 2015 mimi.vx@gmail.com
- add constraints file
* Tue Feb  3 2015 mimi.vx@gmail.com
- remove dblatex dependency
* Mon Jan 12 2015 peter.trommler@ohm-hochschule.de
- add patch 0001-implement-native-code-generator-for-ppc64.patch
  * native code generation improved compilation speed
  * fewer errors in testsuite than with C back end
* Sat Dec 13 2014 peter.trommler@ohm-hochschule.de
- add patch D560.patch
  * fixes dynamic linking on ppc
  * see https://phabricator.haskell.org/D560
  * this is a back port of the upstream patch
* Wed Nov  5 2014 peter.trommler@ohm-hochschule.de
- add patch D349.patch
  * fix a crash with dynamic linking in GHCi when accessing the
  process environment
  * our patch has been submitted upstream
  * see https://phabricator.haskell.org/D349
* Sun Sep 28 2014 peter.trommler@ohm-hochschule.de
- ghc-rpm-macros use internal dependency generator now
  * simplifies spec file
* Sat Sep 20 2014 peter.trommler@ohm-hochschule.de
- fix alternatives handling
* Fri Sep 19 2014 peter.trommler@ohm-hochschule.de
- update to 7.8.3
  * needed for Haskell Platfoerm 2014.2.0.0
  * fixes bnc #726744
  * way smaller source tarball (windows binaries removed)
  * dynamic libraries, GHCi, and Template Haskell for ppc64 and ppc64le
- drop ghc-ppc64le.patch (fixed upstream)
- add integer-gmp.patch
  * build bundled libgmp on SLE 11 (system version is too old)
  * fixes build on x86_64
  * see upstream trac #8156
- add ghc-7.8.2-cgen-constify.patch
  * C backend (ppc64, ppc64le): generate 'const' strings
  * reduce size of table of contents (TOC)
- add D173.patch
  * fix C backend: generate literals of correct size
  * fixes lots of arithmetic failures and trac #8849
  * asked upstream to merge fix into 7.8.4
- add D177.patch
  * pass PIC flags to assembler
  * shared libraries on ppc still broken (trac #8024)
- add ghc.git-e18525f.patch
  * fix C backend: generate functions for cmm primitives
- drop ghc-use-system-libffi.patch (included upstream)
- drop ghc-suse-as-needed.patch (fixed upstream)
- drop Cabal-fix-dynamic-exec-for-TH.patch (fixed upstream)
- drop ghc-7.6.3-LlvmCodeGen-no-3.3-warning.patch (fixed upstream)
- drop ghc-avoid-empty-llvm-used-definitions.patch (fixed upstream)
- drop 0001-Fix-detection-of-library-for-shm-on-openSUSE.patch
  * our patch was included upstream
- drop 0001-Delete-spurious-comma-in-configure.ac.patch
  * our patch was included upstream
-drop ghc-fix-infinite-loop-big-endian.patch (fixed upstream
- refresh llvm-powerpc64-datalayout.patch
  * port to new LLVM backend
- refresh ghc-cabal-unversion-docdir.patch
  * include original Fedora patch for 7.8.2
* Tue Sep 16 2014 peter.trommler@ohm-hochschule.de
- bootstrap from ghc-bootstrap not ghc
  * remove BR loop ghc->ghc
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Sat May 10 2014 dvaleev@suse.com
- Enable ppc64le (ghc-ppc64le.patch)
* Mon Dec 16 2013 peter.trommler@ohm-hochschule.de
- use correct setting for unregisterised builds (ppc64)
- simplify build setup (generation of mk/build.mk)
* Mon Dec 16 2013 peter.trommler@ohm-hochschule.de
- don't BR llvm for now
- dblatex broken on older openSUSE
* Sun Dec 15 2013 peter.trommler@ohm-hochschule.de
- revert LLVM for ppc64 (segfaults during package install)
- fix setting up build.mk
- build perf for all archs
* Sat Dec 14 2013 peter.trommler@ohm-hochschule.de
- Add llvm-powerpc64-datalayout.patch
  * fix LLVM backend for powerpc64
- build and test LLVM backend on powerpc64
* Fri Dec 13 2013 peter.trommler@ohm-hochschule.de
- Add cabal-unversion-docdir.patch
  * ghc-rpm-macros don't include versions in package docdirs
  starting with version 1.0
- use standard docdir for ghc
- package pdf and ps manuals
* Mon Oct 28 2013 peter.trommler@ohm-hochschule.de
- Add ghc-fix-infinite-loop-big-endian.patch: Fix Haskell trac
  [#8134] on ppc64.
- Enable threaded runtime on ppc64
* Tue Sep 24 2013 peter.trommler@ohm-hochschule.de
- Add 0001-Fix-detection-of-library-for-shm-on-openSUSE.patch:
  Fix broken autoconf test for shm_* and librt. Haskell trac #8350
- Add 0001-Delete-spurious-comma-in-configure.ac.patch:
  Fix test for setitimer. Haskell trac #8352
* Tue Sep 24 2013 peter.trommler@ohm-hochschule.de
- set up build.mk with configuration for ppc64
  * explicitly disable features that are not supported on ppc64
* Mon Sep 23 2013 peter.trommler@ohm-hochschule.de
- add BR binutils-devel for bfd.h and libiberty
* Mon Sep 23 2013 peter.trommler@ohm-hochschule.de
- add BR libelf-devel for nlist.h
* Tue Sep 10 2013 peter.trommler@ohm-hochschule.de
- Patches for llvm 3.3.
  * Add ghc-7.6.3-LlvmCodeGen-no-3.3-warning.patch: Silence warning
  about llvm too new
  * Add ghc-avoid-empty-llvm-used-definitions.patch: Fix llvm code
  generator. Backported patch for ghc 7.7 (cf Haskell trac #7996)
- explicitly configure gcc location in bootstrap builds too
- allow ppc builds (ppc64 build gets stuck)
* Fri Sep  6 2013 peter.trommler@ohm-hochschule.de
- include BuildFlavour definitions in build.mk
* Tue Sep  3 2013 peter.trommler@ohm-hochschule.de
- build optimized compiler (BuildFlavour = perf)
- bring back Fedora's Template Haskell patch
- add Haskell trac ticket number to glibc-locale comment
* Tue Jul 16 2013 peter.trommler@ohm-hochschule.de
- add comment to explain why glibc-locale is required by
  ghc-compiler
* Fri May 17 2013 peter.trommler@ohm-hochschule.de
- glibc-locale required by ghc-pkg
* Fri May  3 2013 peter.trommler@ohm-hochschule.de
- update to 7.6.3 from upstream
- part of Haskell Platform 2013.2
- new languages features (polymorphic kinds, ...)
- do compiler upgrade in one submit request by bootstrapping
  ghc if necessary and use that ghc to selfbootstrap new
  ghc
- replaced ghc-use-system-libffi.patch with new patch for
  Haskell trac #5743 (add configure option to use system libffi)
- drop Cabal-fix-dynamic-exec-for-TH.patch: Fixed upstream
- drop ghc-6.12.1-gen_contents_index-haddock-path.patch which used
  system provided haddock and that causes trouble when bootstrapping
- drop ghc-gen_contents_index-type-level.patch: fixed upstream
- drop patch ghc-fix-undefined-openpty.patch: Fixed upstream
- drop patch 0001-Add-missing-flag-for-respecting-EXTRA_LIBDIR.patch:
  Fixed upstream
- port to new ghc-rpm-macros
* Fri Jan 11 2013 peter.trommler@ohm-hochschule.de
- enable color and links in documentation
* Mon Dec  3 2012 peter.trommler@ohm-hochschule.de
- try to work around factory-auto still thinking we need
  to wait for BRs even when those are in a comment
* Wed Nov 28 2012 peter.trommler@ohm-hochschule.de
- help factory-auto by commenting out currently unneeded BRs
* Tue Nov 13 2012 peter.trommler@ohm-hochschule.de
- selfbootstrap ghc 7.4.2
* Mon Nov 12 2012 peter.trommler@ohm-hochschule.de
- remove binary distributions after bootstrap in Factory
* Thu Nov  8 2012 peter.trommler@ohm-hochschule.de
- Update to version 7.4.2 from upstream
  * Required by Haskell Platform 2012.4.0.0
  * Fixes for ghc and ghci
* Thu Nov  8 2012 peter.trommler@ohm-hochschule.de
- add ExclusiveArch tag
* Tue Nov  6 2012 peter.trommler@ohm-hochschule.de
- generate debug packages for Factory
* Sun Oct 14 2012 peter.trommler@ohm-hochschule.de
- do not warn about metapackage ghc containing no binary
* Sat Oct 13 2012 peter.trommler@ohm-hochschule.de
- fix cyclic dependency to ghc (libraries reqire ghc-compiler)
* Fri Oct 12 2012 peter.trommler@ohm-hochschule.de
- do not override automatic dependency generation
  * needs ghc-pkg which we won't have in Factory yet
* Fri Oct 12 2012 peter.trommler@ohm-hochschule.de
- prepare for bootstrap in Factory
  * add binary distribution to spec file
  * change build to use ghc provided by binary distribution
* Tue Jul 31 2012 peter.trommler@ohm-hochschule.de
- back ported two patches for Haskell trac #7062
  * fix openpty undefined symbol
  * fix extra libraries not on linker path
* Sat Jul 28 2012 peter.trommler@ohm-hochschule.de
- fix ghc-suse-as-needed.patch
  * add --disable-new-dtags to linker flags. Adding RUNPATH to shared
  libraries breaks linking. To fix that ghc's libraries need to set
  their own RUNPATHs which they currently don't.
  * fixes Haskell #7062
* Mon Jun 25 2012 peter.trommler@ohm-hochschule.de
- use ghc_lib_subpackage instead of ghc_binlib_package (ghc-rpm-macros 0.95.5.1)
- add simple checks to %%check section
- sort BuildRequires somewhat
* Sun Jun 24 2012 peter.trommler@ohm-hochschule.de
- remove perl boot comment
- rebuild after project conf fix for hscolour (keep deepseq)
* Wed Jun 20 2012 peter.trommler@ohm-hochschule.de
- enable hscolour after bootstrap
* Wed Jun  6 2012 peter.trommler@ohm-hochschule.de
- disable bootstrapping for devel:languagaes:haskell
* Wed Jun  6 2012 peter.trommler@ohm-hochschule.de
- set bootstrapping for bootstrap in devel:languages:haskell
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- add autoreconf required by suse as-needed patch
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- selfbootstraping
- disable perl boot, might undo libffi patch
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- upgrade to 7.4.1 from upstream for Haskell Platform 2012.2.0.0
- drop Cabal-option-executable-dynamic.patch (fixed in upstream)
- add ghc-suse-as-needed.patch
- add Cabal-fix-dynamic-exec-for-TH.patch
- add ghc-gen_contents_index-type-level.patch
- bootstrapping
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- apply patch 2
- use perl boot to autoreconf all subdirectories
* Mon May 28 2012 peter.trommler@ohm-hochschule.de
- added LICENSE to library and base package
- should probably be ignored in rpmlintrc
* Mon May 28 2012 peter.trommler@ohm-hochschule.de
- follow Fedora packaging:
- package compiler in ghc-compiler
- meta package for all libraries
- ghc became meta package for everything
* Sat May 26 2012 peter.trommler@ohm-hochschule.de
- deleted extra BR after project configuration fix
* Fri May 25 2012 peter.trommler@ohm-hochschule.de
- remove minimum version requirement for gmp-devel
* Sat May 19 2012 peter.trommler@ohm-hochschule.de
- don't pack manual page when without_manual is set
* Sat May 19 2012 peter.trommler@ohm-hochschule.de
- temporarily disable manual to work around broken texlive
* Thu May 17 2012 peter.trommler@ohm-hochschule.de
- clean up BuildRequires (one per line)
- force gmp-devel >= 5 to get rid of libgmp.so.3 in Factory
* Mon Mar 12 2012 peter.trommler@ohm-hochschule.de
- enabled hscolour
* Fri Feb  3 2012 peter.trommler@ohm-hochschule.de
- selfbootstrapping
* Fri Feb  3 2012 peter.trommler@ohm-hochschule.de
- disable dependecy generator during bootstrap
* Thu Feb  2 2012 peter.trommler@ohm-hochschule.de
- bootstrap SLE11-SP1
* Mon Jan 23 2012 peter.trommler@ohm-hochschule.de
- provide ghc-compiler = %%{version}
* Mon Jan 23 2012 peter.trommler@ohm-hochschule.de
- package HSffi.o on 11.3
* Sun Jan 22 2012 peter.trommler@ohm-hochschule.de
- done bootstrapping
* Sun Jan 22 2012 peter.trommler@ohm-hochschule.de
- Move documentation to new place
- Fix douple packaging
* Mon Jan 16 2012 peter.trommler@ohm-hochschule.de
- Added haddock patch
- Fixed many file packaged twice issues
* Wed Jan  4 2012 peter.trommler@ohm-hochschule.de
- Enabled hscolour
- Prepared for libffi patch (needs fix fo bnc#711489)
* Thu Dec 29 2011 peter.trommler@ohm-hochschule.de
- Lowered ghc BR to 6.10
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Added Cabal patch (required for ghc-rpm-macros)
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- unset bootstrapping
- additional BR that should not be required
* Tue Dec 27 2011 peter.trommler@ohm-hochschule.de
- Fixed versions and names in libraries
- Fixed files section
* Thu Dec 22 2011 peter.trommler@ohm-hochschule.de
- Start version 7.0.4
